### Stay Informed

Receive updates on new releases and upcoming projects.

Follow @nicolaiarocci

Join Mailing List.

### Eve Course

This course will teach you how to build RESTful services with Eve and MongoDB.

The teacher is the project creator and maintainer.

- Eve Course @ TalkPython

### Useful Links

- Eve @ GitHub
- Eve @ Stack Overflow
- Eve @ Google Groups
- Eve @ IRC
- Eve @ PyPI
- Eve @ Nicola Iarocci
- Issue Tracker

### Other Projects

More Nicola Iarocci projects:

- Cerberus
- Events
- Flask-Sentinel
- Flask-MimeRender
- Eve-Demo
- Eve-Demo Client
- Eve-Swagger
- Eve-OAuth2